Capitalization enum

Capilization of the characters. allwaysAllcaps - Character is converted to allcaps alwaysSmall - Character is converted to lowercaps keyboardDefined - Character is defined by the keyboard (default)

Inheritance
Available extensions

Values

alwaysAllcaps → const Capitalization
alwaysSmall → const Capitalization
keyboardDefined → const Capitalization

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Capitalization>
A constant List of the values in this enum, in order of their declaration.