onChanged property

void Function(List<String>) onChanged
final

A callback function that is called whenever the list of characters changes. It provides the current list of characters in all boxes.

Implementation

final void Function(List<String>) onChanged;