CodeEntryFieldStyle class
Defines the visual styling for the CodeEntryField widget.
- Annotations
Constructors
- CodeEntryFieldStyle({Color? boxBackgroundColor, Color? boxBorderColor, double? boxBorderWidth, double? boxCornerRadius, Color? selectionColor, TextStyle? textStyle})
-
Creates a CodeEntryFieldStyle instance.
const
Properties
- boxBackgroundColor → Color?
-
The background color of each character box.
final
- boxBorderColor → Color?
-
The color of the border around each character box.
final
- boxBorderWidth → double?
-
The width of the border around each character box.
final
- boxCornerRadius → double?
-
The radius for the corners of each character box.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color?
-
The color of the selection highlight when a box is focused.
final
- textStyle → TextStyle?
-
The text style for the characters entered in the boxes.
final
Methods
-
copyWith(
{Color? boxBackgroundColor, Color? boxBorderColor, double? boxBorderWidth, double? cornerRadius, Color? selectionColor, TextStyle? textStyle}) → CodeEntryFieldStyle - copyWith method for changing default style values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- Default → CodeEntryFieldStyle
-
The deafult style of the widget
final